Tableau Migration SDK 6.1.0
  • Articles
  • Code Samples
  • Python API Reference
  • C# API Reference
Show / Hide Table of Contents
  • tableau_migration
    • migration
      • get_service_provider
      • get_service
      • reload_configuration
      • PyContentLocation
      • PyContentReference
      • PyEmptyIdContentReference
      • PyMigrationCompletionStatus
      • PyMigrationManifest
      • PyMigrationResult
      • PyPipelineProfile
      • PyResult
    • migration_api_rest
      • PyRestIdentifiable
    • migration_api_rest_models
      • PyAdministratorLevels
      • PyContentPermissions
      • PyExtractEncryptionModes
      • PyLabelCategories
      • PyLicenseLevels
      • PyPermissionsCapabilityModes
      • PyPermissionsCapabilityNames
      • PySiteRoles
    • migration_api_rest_models_types
      • PyAuthenticationTypes
      • PyDataSourceFileTypes
      • PyFlowFileTypes
      • PyWorkbookFileTypes
    • migration_content
      • PyCloudSubscription
      • PyConnection
      • PyConnectionsContent
      • PyContainerContent
      • PyCustomView
      • PyDataSource
      • PyDataSourceDetails
      • PyDescriptionContent
      • PyUserAuthenticationType
      • PyUsernameContent
      • PyView
      • PyWithDomain
      • PyWithOwner
      • PyWithTags
      • PyWithWorkbook
      • PyWorkbook
      • PyWorkbookDetails
      • PyUser
      • PyTag
      • PySubscriptionContent
      • PySubscription
      • PyExtractContent
      • PyFavorite
      • PyFavoriteContentType
      • PyFlow
      • PyFlowDetails
      • PyFlowOutputStep
      • PyGroup
      • PyGroupSet
      • PyGroupUser
      • PyLabel
      • PyPublishableCustomView
      • PyPublishableDataSource
      • PyPublishableFlow
      • PyPublishableGroup
      • PyPublishableGroupSet
      • PyPublishableWorkbook
      • PyPublishedContent
      • PyServerSubscription
      • PySizeContent
      • PyProject
    • migration_content_permissions
      • PyPermissionSet
      • PyGranteeType
      • PyCapability
      • PyGranteeCapability
      • PyPermissions
    • migration_content_schedules
      • PyExtractRefreshContentType
      • PyExtractRefreshTask
      • PyFrequencyDetails
      • PyInterval
      • PySchedule
      • PyWithSchedule
    • migration_content_schedules_cloud
      • PyCloudExtractRefreshTask
      • PyCloudSchedule
    • migration_content_schedules_server
      • PyServerExtractRefreshTask
      • PyServerSchedule
    • migration_content_search
      • PyContentReferenceFinder
    • migration_engine
      • PyServerToCloudMigrationPlanBuilder
      • PyMigrationPlanEndpointConfiguration
      • PyMigrationPlanBuilder
      • PyContentMigrationItem
      • PyMigrationPlan
      • PyMigrationPlanEndpointBuilder
    • migration_engine_actions
      • PyMigrationActionResult
    • migration_engine_endpoints_caching
      • BulkContentReferenceCacheLoadStrategyProvider
      • ContentReferenceCacheLoadStrategyProviderBase
      • LazyContentReferenceCacheLoadStrategyProvider
    • migration_engine_endpoints_search
      • PySourceContentReferenceFinderFactory
      • PySourceContentReferenceFinderBase
      • PySourceContentReferenceFinder
      • PyDestinationContentReferenceFinder
      • PyDestinationContentReferenceFinderBase
      • PyDestinationContentReferenceFinderFactory
    • migration_engine_hooks
      • PyMigrationHookFactoryCollection
    • migration_engine_hooks_builder
      • PyMigrationHookBuilder
    • migration_engine_hooks_filters
      • PyContentFilterContext
      • PyContentFilterContextItem
      • PyFilterStatus
    • migration_engine_hooks_filters_builder
      • PyContentFilterBuilder
    • migration_engine_hooks_filters_interop
      • PyContentFilterBase
    • migration_engine_hooks_initializemigration
      • PyInitializeMigrationHookResult
    • migration_engine_hooks_interop
      • PyContentBatchMigrationCompletedHookBase
      • PyInitializeMigrationHookBase
      • PyMigrationActionCompletedHookBase
    • migration_engine_hooks_mappings
      • PyContentMappingContext
    • migration_engine_hooks_mappings_builder
      • PyContentMappingBuilder
    • migration_engine_hooks_mappings_interop
      • PyTableauCloudUsernameMappingBase
      • PyContentMappingBase
    • migration_engine_hooks_postpublish
      • PyBulkPostPublishContext
      • PyContentItemPostPublishContext
    • migration_engine_hooks_postpublish_interop
      • PyBulkPostPublishHookBase
      • PyContentItemPostPublishHookBase
    • migration_engine_hooks_pulled
      • PyContentItemPulledContext
    • migration_engine_hooks_pulled_interop
      • PyContentItemPulledHookBase
    • migration_engine_hooks_transformers_builder
      • PyContentTransformerBuilder
    • migration_engine_hooks_transformers_interop
      • PyContentTransformerBase
      • PyJsonContentTransformerBase
      • PyXmlContentTransformerBase
    • migration_engine_manifest
      • PyMigrationManifestEntry
      • PyMigrationManifestEntryEditor
      • PyMigrationManifestEntryStatus
      • PyMigrationManifestSerializer
    • migration_engine_migrators
      • PyContentItemMigrationResult
      • PyMigrator
    • migration_engine_migrators_batch
      • PyContentBatchMigrationResult
    • migration_engine_options
      • PyMigrationPlanOptionsBuilder
      • PyMigrationPlanOptionsCollection
    • migration_engine_pipelines
      • PyMigrationPipelineContentType
      • PyServerToCloudMigrationPipeline
    • migration_engine_services
      • PyMigrationContentLoaderBase
      • PyMigrationServiceBuilder
      • PyMigrationServiceFactoryCollection
      • PyMigrationServiceFactoryContext
      • PyServiceType
    • migration_enum
    • migration_interop
    • migration_logger
      • MigrationLogger
    • migration_paging
      • empty_pager
      • memory_pager
    • migration_services
      • ScopedMigrationServices

PyFlowDetails

class PyFlowDetails(flow_details)

Bases: PyFlow

Interface for a flow object with extended information, from a GET query for example.

  • Parameters: flow_details (IFlowDetails)

__init__(flow_details)

Creates a new PyFlowDetails object.

Args: : flow_details: A IFlowDetails object.

Returns: None.

  • Parameters: flow_details (IFlowDetails)
  • Return type: None

Methods

__init__(flow_details) Creates a new PyFlowDetails object.

Attributes

container Gets the container for the content item.
content_url Get the site-unique "content URL" of the content item, or an empty string if the content type does not use a content URL.
created_at Gets the created timestamp.
description Gets or sets the description.
file_type Get or sets the prep flow file type.
flow_output_steps Gets the flow output step metadata.
id Gets the unique identifier.
location Gets the logical location path of the content item, for project-level content this is the project path and the content item name.
name Gets the name of the content item.
owner Gets or sets the owner for the content item.
tags Gets or sets the tags for the content item.
updated_at Gets the updated timestamp.
webpage_url Gets the webpage URL.

property flow_output_steps : Sequence[PyFlowOutputStep]

Gets the flow output step metadata.

property container : PyContentReference

Gets the container for the content item. Relocating the content should be done through mapping.

property content_url : str

Get the site-unique “content URL” of the content item, or an empty string if the content type does not use a content URL.

property created_at : str

Gets the created timestamp.

property description : str

Gets or sets the description.

property file_type : str

Get or sets the prep flow file type.

property id : UUID

Gets the unique identifier.

property location : PyContentLocation

Gets the logical location path of the content item, for project-level content this is the project path and the content item name.

property name : str

Gets the name of the content item. This is equivalent to the last segment of the Location. Renames should be performed through mapping.

property owner : PyContentReference

Gets or sets the owner for the content item.

property tags : Sequence[PyTag]

Gets or sets the tags for the content item.

property updated_at : str

Gets the updated timestamp.

property webpage_url : str

Gets the webpage URL.

In this article