PySubscriptionContent
class PySubscriptionContent(subscription_content)
Bases: PyContentReference
The content of the subscription.
- Parameters: subscription_content (ISubscriptionContent)
__init__(subscription_content)
Creates a new PySubscriptionContent object.
Args: : subscription_content: A ISubscriptionContent object.
Returns: None.
- Parameters: subscription_content (ISubscriptionContent)
- Return type: None
Methods
__init__(subscription_content) |
Creates a new PySubscriptionContent object. |
|---|---|
for_reference(reference) |
Creates a new ISubscriptionContent object of the same type for the new content reference. |
Attributes
content_url |
Get the site-unique "content URL" of the content item, or an empty string if the content type does not use a content URL. |
|---|---|
id |
Gets the unique identifier. |
location |
Gets the logical location path of the content item, for project-level content this is the project path and the content item name. |
name |
Gets the name of the content item. |
send_if_view_empty |
Whether or not send the notification if the view is empty. |
type |
The content type of the subscription. |
property type : str
The content type of the subscription.
property send_if_view_empty : bool
Whether or not send the notification if the view is empty.
for_reference(reference)
Creates a new ISubscriptionContent object of the same type for the new content reference.
Args: : reference: The new content reference.
Returns: The created ISubscriptionContent.
- Parameters: reference (PyContentReference)
- Return type: Self
property content_url : str
Get the site-unique “content URL” of the content item, or an empty string if the content type does not use a content URL.
property id : UUID
Gets the unique identifier.
property location : PyContentLocation
Gets the logical location path of the content item, for project-level content this is the project path and the content item name.
property name : str
Gets the name of the content item. This is equivalent to the last segment of the Location. Renames should be performed through mapping.