tableau_migration.migration_engine
Wrapper for classes in Tableau.Migration.Engine namespace.
Classes
PyContentMigrationItem(content_migration_item) |
Record containing in-progress migration state for a content item. |
|---|---|
PyMigrationPlan(migration_plan) |
Default IMigrationPlan implementation. |
PyMigrationPlanBuilder() |
Default IMigrationPlanBuilder implementation. |
PyMigrationPlanEndpointBuilder(builder) |
Interface for an object that can edit endpoints during plan building. |
PyMigrationPlanEndpointConfiguration(config) |
Interface for configuration necessary to connect to a migration endpoint defined in the IMigrationPlan. |
PyServerToCloudMigrationPlanBuilder(...) |
Default IServerToCloudMigrationPlanBuilder implementation. |