Tableau Migration SDK 6.0.0
  • Articles
  • Code Samples
  • Python API Reference
  • C# API Reference
Show / Hide Table of Contents
  • tableau_migration
    • migration
      • get_service_provider
      • get_service
      • reload_configuration
      • PyContentLocation
      • PyContentReference
      • PyEmptyIdContentReference
      • PyMigrationCompletionStatus
      • PyMigrationManifest
      • PyMigrationResult
      • PyPipelineProfile
      • PyResult
    • migration_api_rest
      • PyRestIdentifiable
    • migration_api_rest_models
      • PyAdministratorLevels
      • PyContentPermissions
      • PyExtractEncryptionModes
      • PyLabelCategories
      • PyLicenseLevels
      • PyPermissionsCapabilityModes
      • PyPermissionsCapabilityNames
      • PySiteRoles
    • migration_api_rest_models_types
      • PyAuthenticationTypes
      • PyDataSourceFileTypes
      • PyWorkbookFileTypes
    • migration_content
      • PyCloudSubscription
      • PyConnection
      • PyConnectionsContent
      • PyContainerContent
      • PyCustomView
      • PyUser
      • PyUserAuthenticationType
      • PyUsernameContent
      • PyView
      • PyWithDomain
      • PyWithOwner
      • PyWithTags
      • PyWithWorkbook
      • PyWorkbook
      • PyWorkbookDetails
      • PyTag
      • PySubscriptionContent
      • PySubscription
      • PySizeContent
      • PyDataSource
      • PyDataSourceDetails
      • PyDescriptionContent
      • PyExtractContent
      • PyFavorite
      • PyFavoriteContentType
      • PyGroup
      • PyGroupSet
      • PyGroupUser
      • PyProject
      • PyPublishableCustomView
      • PyPublishableDataSource
      • PyPublishableGroup
      • PyPublishableGroupSet
      • PyPublishableWorkbook
      • PyPublishedContent
      • PyServerSubscription
      • PyLabel
    • migration_content_permissions
      • PyPermissionSet
      • PyPermissions
      • PyGranteeCapability
      • PyCapability
      • PyGranteeType
    • migration_content_schedules
      • PyExtractRefreshContentType
      • PyExtractRefreshTask
      • PyFrequencyDetails
      • PyInterval
      • PySchedule
      • PyWithSchedule
    • migration_content_schedules_cloud
      • PyCloudExtractRefreshTask
      • PyCloudSchedule
    • migration_content_schedules_server
      • PyServerExtractRefreshTask
      • PyServerSchedule
    • migration_content_search
      • PyContentReferenceFinder
    • migration_engine
      • PyMigrationPlanEndpointConfiguration
      • PyContentMigrationItem
      • PyMigrationPlan
      • PyMigrationPlanBuilder
      • PyMigrationPlanEndpointBuilder
      • PyServerToCloudMigrationPlanBuilder
    • migration_engine_actions
      • PyMigrationActionResult
    • migration_engine_endpoints_caching
      • BulkContentReferenceCacheLoadStrategyProvider
      • ContentReferenceCacheLoadStrategyProviderBase
      • LazyContentReferenceCacheLoadStrategyProvider
    • migration_engine_endpoints_search
      • PySourceContentReferenceFinderBase
      • PySourceContentReferenceFinderFactory
      • PySourceContentReferenceFinder
      • PyDestinationContentReferenceFinderFactory
      • PyDestinationContentReferenceFinderBase
      • PyDestinationContentReferenceFinder
    • migration_engine_hooks
      • PyMigrationHookBuilder
      • PyMigrationHookFactoryCollection
    • migration_engine_hooks_filters
      • PyContentFilterBuilder
    • migration_engine_hooks_filters_interop
      • PyContentFilterBase
    • migration_engine_hooks_initializemigration
      • PyInitializeMigrationHookResult
    • migration_engine_hooks_interop
      • PyContentBatchMigrationCompletedHookBase
      • PyInitializeMigrationHookBase
      • PyMigrationActionCompletedHookBase
    • migration_engine_hooks_mappings
      • PyContentMappingContext
      • PyContentMappingBuilder
    • migration_engine_hooks_mappings_interop
      • PyContentMappingBase
      • PyTableauCloudUsernameMappingBase
    • migration_engine_hooks_postpublish
      • PyBulkPostPublishContext
      • PyContentItemPostPublishContext
    • migration_engine_hooks_postpublish_interop
      • PyContentItemPostPublishHookBase
      • PyBulkPostPublishHookBase
    • migration_engine_hooks_transformers
      • PyContentTransformerBuilder
    • migration_engine_hooks_transformers_interop
      • PyContentTransformerBase
      • PyXmlContentTransformerBase
    • migration_engine_manifest
      • PyMigrationManifestEntry
      • PyMigrationManifestEntryEditor
      • PyMigrationManifestEntryStatus
      • PyMigrationManifestSerializer
    • migration_engine_migrators
      • PyMigrator
      • PyContentItemMigrationResult
    • migration_engine_migrators_batch
      • PyContentBatchMigrationResult
    • migration_engine_options
      • PyMigrationPlanOptionsBuilder
      • PyMigrationPlanOptionsCollection
    • migration_engine_pipelines
      • PyMigrationPipelineContentType
      • PyServerToCloudMigrationPipeline
    • migration_engine_services
      • PyMigrationContentLoaderBase
      • PyMigrationServiceBuilder
      • PyMigrationServiceFactoryCollection
      • PyMigrationServiceFactoryContext
      • PyServiceType
    • migration_enum
    • migration_interop
    • migration_logger
      • MigrationLogger
    • migration_paging
      • empty_pager
      • memory_pager
    • migration_services
      • ScopedMigrationServices

PyMigrationPlan

class PyMigrationPlan(migration_plan)

Bases: object

Default IMigrationPlan implementation.

  • Parameters: migration_plan (IMigrationPlan)

__init__(migration_plan)

Default init.

Args: : migration_plan: An object that describes how to perform a migration of Tableau data between sites.

Returns: None.

  • Parameters: migration_plan (IMigrationPlan)
  • Return type: None

Methods

__init__(migration_plan) Default init.

Attributes

destination Gets the defined destination endpoint configuration.
filters Gets the collection of registered filters for each content type.
hooks Gets the collection of registered hooks for each hook type.
mappings Gets the collection of registered mappings for each content type.
options Gets the per-plan options.
pipeline_profile Gets the profile of the pipeline that will be built and executed.
plan_id Gets the per-plan options to supply.
services Gets the collection of registered migration service overrides.
source Gets the defined source endpoint configuration.
transformers Gets the collection of registered transformers for each content type.

property plan_id : UUID

Gets the per-plan options to supply.

property pipeline_profile : PyPipelineProfile

Gets the profile of the pipeline that will be built and executed.

property options : PyMigrationPlanOptionsCollection

Gets the per-plan options.

property source : PyMigrationPlanEndpointConfiguration

Gets the defined source endpoint configuration.

property destination : PyMigrationPlanEndpointConfiguration

Gets the defined destination endpoint configuration.

property services : PyMigrationServiceFactoryCollection

Gets the collection of registered migration service overrides.

property hooks : PyMigrationHookFactoryCollection

Gets the collection of registered hooks for each hook type.

property mappings : PyMigrationHookFactoryCollection

Gets the collection of registered mappings for each content type.

property filters : PyMigrationHookFactoryCollection

Gets the collection of registered filters for each content type.

property transformers : PyMigrationHookFactoryCollection

Gets the collection of registered transformers for each content type.

In this article