PyServerToCloudMigrationPlanBuilder
class PyServerToCloudMigrationPlanBuilder(_plan_builder)
Bases: object
Default IServerToCloudMigrationPlanBuilder implementation.
- Parameters: _plan_builder (IServerToCloudMigrationPlanBuilder)
__init__(_plan_builder)
Default init.
Args: : _plan_builder: An object that can build IMigrationPlan objects that migrate content from Tableau Server to Tableau Cloud.
Returns: None.
- Parameters: _plan_builder (IServerToCloudMigrationPlanBuilder)
- Return type: None
Methods
__init__(_plan_builder) |
Default init. |
|---|---|
append_default_extensions() |
Adds default hooks, filters, etc. |
append_default_server_to_cloud_extensions() |
Appends default hooks, filters, mappings, and transformations for server-to-cloud migrations. |
build() |
Finalizes the IMigrationPlan based on the current state. |
clear_extensions() |
Clears all hooks, filters, mappings, and transformations. |
for_server_to_cloud() |
Initializes the plan to perform a migration of content between a Tableau Server and Tableau Cloud site. |
from_source(config) |
Sets or overwrites the configuration for the source endpoint to migrate content from. |
from_source_tableau_server(server_url, ...) |
Sets or overwrites the configuration for the source Tableau Server site to migrate content from. |
skip_content_type(content_type[, pre_cache]) |
Configures the migration plan to skip migration of all items of a particular content type. |
to_destination(config) |
Sets or overwrites the configuration for the destination endpoint to migrate content to. |
to_destination_tableau_cloud(pod_url, ...[, ...]) |
Sets or overwrites the configuration for the destination Tableau Cloud site to migrate content to. |
validate() |
Validates that the plan that would be built has enough information to execute. |
with_authentication_type(...) |
Adds an object to map user and group domains based on the destination authentication type. |
with_saml_authentication_type(domain[, ...]) |
Adds an object to map user and group domains based on the SAML authentication type. |
with_tableau_cloud_usernames(input_0[, ...]) |
Adds an object to map usernames to be in the form of an email. |
with_tableau_id_authentication_type([mfa, ...]) |
Adds an object to map user and group domains based on the Tableau ID authentication type. |
Attributes
destination |
Gets the destination endpoint builder. |
|---|---|
filters |
Gets the filters to execute at various points during the migration. |
hooks |
Gets the hooks to execute at various points during the migration, determined by hook type. |
mappings |
Gets the mappings to execute at various points during the migration. |
options |
Gets the per-plan options to supply. |
pipeline_profile |
Gets the profile of the pipeline that will be built and executed. |
services |
Gets the migration service overrides. |
source |
Gets the source endpoint builder. |
transformers |
Gets the transformations to execute at various points during the migration. |
property source : PyMigrationPlanEndpointBuilder
Gets the source endpoint builder.
property destination : PyMigrationPlanEndpointBuilder
Gets the destination endpoint builder.
property filters : PyContentFilterBuilder
Gets the filters to execute at various points during the migration.
property transformers : PyContentTransformerBuilder
Gets the transformations to execute at various points during the migration.
property options : PyMigrationPlanOptionsBuilder
Gets the per-plan options to supply.
property services : PyMigrationServiceBuilder
Gets the migration service overrides.
property hooks : PyMigrationHookBuilder
Gets the hooks to execute at various points during the migration, determined by hook type.
property mappings : PyContentMappingBuilder
Gets the mappings to execute at various points during the migration.
property pipeline_profile : PyPipelineProfile
Gets the profile of the pipeline that will be built and executed.
from_source_tableau_server(server_url, site_content_url, access_token_name, access_token, create_api_simulator=False, rest_api_version=None)
Sets or overwrites the configuration for the source Tableau Server site to migrate content from.
Args: : server_url: The base URL of the Tableau Server to connect to. site_content_url: The URL namespace of the site to connect to. access_token_name: The name of the personal access token to use to sign into the site. access_token: The personal access token to use to sign into the site. create_api_simulator: Whether or not to create an API simulator for the server_url. rest_api_version: The REST API version to use, or null to use the default version.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- server_url (str)
- site_content_url (str)
- access_token_name (str)
- access_token (str)
- create_api_simulator (bool)
- rest_api_version (str | None)
- Return type: Self
to_destination_tableau_cloud(pod_url, site_content_url, access_token_name, access_token, create_api_simulator=False, rest_api_version=None)
Sets or overwrites the configuration for the destination Tableau Cloud site to migrate content to.
Args: : pod_url: The base URL of Tableau Cloud pod to connect to. site_content_url: The URL namespace of the site to connect to. access_token_name: The name of the personal access token to use to sign into the site. access_token: The personal access token to use to sign into the site. create_api_simulator: Whether or not to create an API simulator for the server_url. rest_api_version: The REST API version to use, or null to use the default version.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- pod_url (str)
- site_content_url (str)
- access_token_name (str)
- access_token (str)
- create_api_simulator (bool)
- rest_api_version (str | None)
- Return type: Self
skip_content_type(content_type, pre_cache=True)
Configures the migration plan to skip migration of all items of a particular content type.
Args: : content_type: The content type to skip. pre_cache: True to find and map all source items so references in dependent content types can be efficiently updated. False to find and map items individually when they are referenced in dependent content types to avoid listing all items.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- content_type (type)
- pre_cache (bool)
- Return type: Self
for_server_to_cloud()
Initializes the plan to perform a migration of content between a Tableau Server and Tableau Cloud site.
Returns: The same plan builder object for fluent API calls.
- Return type: Self
build()
Finalizes the IMigrationPlan based on the current state.
Returns: The created IMigrationPlan.
- Return type: PyMigrationPlan
clear_extensions()
Clears all hooks, filters, mappings, and transformations.
Returns: The same plan builder object for fluent API calls.
- Return type: Self
append_default_extensions()
Adds default hooks, filters, etc. that are common between all migration scenarios.
Returns: The same plan builder object for fluent API calls.
- Return type: Self
from_source(config)
Sets or overwrites the configuration for the source endpoint to migrate content from.
Args: : config: The endpoint configuration.
Returns: The same plan builder object for fluent API calls.
- Parameters: config (IMigrationPlanEndpointConfiguration)
- Return type: Self
to_destination(config)
Sets or overwrites the configuration for the destination endpoint to migrate content to.
Args: : config: The endpoint configuration.
Returns: The same plan builder object for fluent API calls.
- Parameters: config (IMigrationPlanEndpointConfiguration)
- Return type: Self
validate()
Validates that the plan that would be built has enough information to execute.
Returns: The validation result.
- Return type: PyResult
append_default_server_to_cloud_extensions()
Appends default hooks, filters, mappings, and transformations for server-to-cloud migrations.
This method is intended for upgrading existing plan builders -
new plan builders should use
Returns: The same plan builder object for fluent API calls.
- Return type: Self
with_saml_authentication_type(domain, idp_configuration_name=None)
Adds an object to map user and group domains based on the SAML authentication type.
Args: : domain: The domain to map users and groups to. idp_configuration_name: The IdP configuration name for the authentication type to assign to users. Should be null when the destination site is Tableau Server or has a single authentication configuration. Should be non-null when the destination site is Tableau Cloud and has multiple authentication configurations.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- domain (str)
- idp_configuration_name (str | None)
- Return type: Self
with_tableau_id_authentication_type(mfa=True, idp_configuration_name=None)
Adds an object to map user and group domains based on the Tableau ID authentication type.
Args: : mfa: Whether or not MFA is used, defaults to true. idp_configuration_name: The IdP configuration name for the authentication type to assign to users. Should be null when the destination site is Tableau Server or has a single authentication configuration. Should be non-null when the destination site is Tableau Cloud and has multiple authentication configurations.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- mfa (bool)
- idp_configuration_name (str | None)
- Return type: Self
with_authentication_type(authentication_type, input_1, group_domain)
Adds an object to map user and group domains based on the destination authentication type.
Args: : authentication_type: The authentication type to assign to users. For sites without multiple authentication types an authSetting value from https://help.tableau.com/current/api/rest_api/en-us/REST/rest_api_ref_users_and_groups.htm#add_user_to_site should be used. If the site has multiple authentication types the IdP configuration name shown in the authentication configuration list should be used. input_1: Either 1) the domain to map users to, or 2) the mapping to execute. group_domain: The domain to map users to. Not used with input_1 in a mapping object.
Returns: The same plan builder object for fluent API calls.
- Parameters: authentication_type (str)
- Return type: Self
with_tableau_cloud_usernames(input_0, use_existing_email=True)
Adds an object to map usernames to be in the form of an email.
Args:
: input_0: Either:
: 1. The mapping type to execute, or
2. The callback function to execute, or
3. A string for a domain name to use to build email usernames for users that lack emails. Usernames will be generated as “@{input_0}”.
use_existing_email: Whether or not existing user emails should be used when available, defaults to true. Not used when input_0 is not a string.
Returns: The same plan builder object for fluent API calls.
- Parameters:
- input_0 (type | Callable | str)
- use_existing_email (bool)
- Return type: Self