Tableau Migration SDK 6.0.0
  • Articles
  • Code Samples
  • Python API Reference
  • C# API Reference
Show / Hide Table of Contents
  • tableau_migration
    • migration
      • get_service_provider
      • get_service
      • reload_configuration
      • PyContentLocation
      • PyContentReference
      • PyEmptyIdContentReference
      • PyMigrationCompletionStatus
      • PyMigrationManifest
      • PyMigrationResult
      • PyPipelineProfile
      • PyResult
    • migration_api_rest
      • PyRestIdentifiable
    • migration_api_rest_models
      • PyAdministratorLevels
      • PyContentPermissions
      • PyExtractEncryptionModes
      • PyLabelCategories
      • PyLicenseLevels
      • PyPermissionsCapabilityModes
      • PyPermissionsCapabilityNames
      • PySiteRoles
    • migration_api_rest_models_types
      • PyAuthenticationTypes
      • PyDataSourceFileTypes
      • PyWorkbookFileTypes
    • migration_content
      • PyCloudSubscription
      • PyConnection
      • PyConnectionsContent
      • PyContainerContent
      • PyCustomView
      • PyUser
      • PyUserAuthenticationType
      • PyUsernameContent
      • PyView
      • PyWithDomain
      • PyWithOwner
      • PyWithTags
      • PyWithWorkbook
      • PyWorkbook
      • PyWorkbookDetails
      • PyTag
      • PySubscriptionContent
      • PySubscription
      • PySizeContent
      • PyDataSource
      • PyDataSourceDetails
      • PyDescriptionContent
      • PyExtractContent
      • PyFavorite
      • PyFavoriteContentType
      • PyGroup
      • PyGroupSet
      • PyGroupUser
      • PyProject
      • PyPublishableCustomView
      • PyPublishableDataSource
      • PyPublishableGroup
      • PyPublishableGroupSet
      • PyPublishableWorkbook
      • PyPublishedContent
      • PyServerSubscription
      • PyLabel
    • migration_content_permissions
      • PyPermissionSet
      • PyPermissions
      • PyGranteeCapability
      • PyCapability
      • PyGranteeType
    • migration_content_schedules
      • PyExtractRefreshContentType
      • PyExtractRefreshTask
      • PyFrequencyDetails
      • PyInterval
      • PySchedule
      • PyWithSchedule
    • migration_content_schedules_cloud
      • PyCloudExtractRefreshTask
      • PyCloudSchedule
    • migration_content_schedules_server
      • PyServerExtractRefreshTask
      • PyServerSchedule
    • migration_content_search
      • PyContentReferenceFinder
    • migration_engine
      • PyMigrationPlanEndpointConfiguration
      • PyContentMigrationItem
      • PyMigrationPlan
      • PyMigrationPlanBuilder
      • PyMigrationPlanEndpointBuilder
      • PyServerToCloudMigrationPlanBuilder
    • migration_engine_actions
      • PyMigrationActionResult
    • migration_engine_endpoints_caching
      • BulkContentReferenceCacheLoadStrategyProvider
      • ContentReferenceCacheLoadStrategyProviderBase
      • LazyContentReferenceCacheLoadStrategyProvider
    • migration_engine_endpoints_search
      • PySourceContentReferenceFinderBase
      • PySourceContentReferenceFinderFactory
      • PySourceContentReferenceFinder
      • PyDestinationContentReferenceFinderFactory
      • PyDestinationContentReferenceFinderBase
      • PyDestinationContentReferenceFinder
    • migration_engine_hooks
      • PyMigrationHookBuilder
      • PyMigrationHookFactoryCollection
    • migration_engine_hooks_filters
      • PyContentFilterBuilder
    • migration_engine_hooks_filters_interop
      • PyContentFilterBase
    • migration_engine_hooks_initializemigration
      • PyInitializeMigrationHookResult
    • migration_engine_hooks_interop
      • PyContentBatchMigrationCompletedHookBase
      • PyInitializeMigrationHookBase
      • PyMigrationActionCompletedHookBase
    • migration_engine_hooks_mappings
      • PyContentMappingContext
      • PyContentMappingBuilder
    • migration_engine_hooks_mappings_interop
      • PyContentMappingBase
      • PyTableauCloudUsernameMappingBase
    • migration_engine_hooks_postpublish
      • PyBulkPostPublishContext
      • PyContentItemPostPublishContext
    • migration_engine_hooks_postpublish_interop
      • PyContentItemPostPublishHookBase
      • PyBulkPostPublishHookBase
    • migration_engine_hooks_transformers
      • PyContentTransformerBuilder
    • migration_engine_hooks_transformers_interop
      • PyContentTransformerBase
      • PyXmlContentTransformerBase
    • migration_engine_manifest
      • PyMigrationManifestEntry
      • PyMigrationManifestEntryEditor
      • PyMigrationManifestEntryStatus
      • PyMigrationManifestSerializer
    • migration_engine_migrators
      • PyMigrator
      • PyContentItemMigrationResult
    • migration_engine_migrators_batch
      • PyContentBatchMigrationResult
    • migration_engine_options
      • PyMigrationPlanOptionsBuilder
      • PyMigrationPlanOptionsCollection
    • migration_engine_pipelines
      • PyMigrationPipelineContentType
      • PyServerToCloudMigrationPipeline
    • migration_engine_services
      • PyMigrationContentLoaderBase
      • PyMigrationServiceBuilder
      • PyMigrationServiceFactoryCollection
      • PyMigrationServiceFactoryContext
      • PyServiceType
    • migration_enum
    • migration_interop
    • migration_logger
      • MigrationLogger
    • migration_paging
      • empty_pager
      • memory_pager
    • migration_services
      • ScopedMigrationServices

tableau_migration.migration_engine_endpoints_search

Wrapper for classes in Tableau.Migration.Engine.Endpoints.Search namespace.

Classes

PyDestinationContentReferenceFinder(...) Interface for an object that can find destination content reference for given content information, applying mapping rules.
PyDestinationContentReferenceFinderBase() Generic base class for destination content reference finders.
PyDestinationContentReferenceFinderFactory(...) Interface for an object that can create destination content reference finders based on content type.
PySourceContentReferenceFinder(...) Interface for an object that can find source content reference.
PySourceContentReferenceFinderBase() Generic base class for source content reference finders.
PySourceContentReferenceFinderFactory(...) Interface for an object that can create source content reference finders based on content type.
In this article