tableau_migration.migration_engine_hooks_filters
Wrapper for classes in Tableau.Migration.Engine.Hooks.Filters namespace.
Classes
PyContentFilterContext(content_filter_context) |
Context for IContentFilter operations, determining which items should be migrated and whether to cascade filtering to dependent content types. |
|---|---|
PyContentFilterContextItem(...) |
Context for IContentFilter operations, determining whether a content item should be migrated and whether to cascade filtering to dependent content types. |
PyFilterStatus(value) |
Enumeration of the various filter states for a content item. |